@@ -60,11 +60,11 @@ class Registro(RegistroBase):
             return SituacaoPedido.SITUACAO_PEDIDO_PAGO
         if self.situacao_cancelado:
             return SituacaoPedido.SITUACAO_PEDIDO_CANCELADO
-        return None
+        return SituacaoPedido.SITUACAO_PEDIDO_EFETUADO
 
     @property
     def alterar_situacao(self):
-        return self.situacao_do_pedido is not None
+        return True
 
     @property
     def retorno_de_requisicao(self):
@@ -80,7 +80,7 @@ class Registro(RegistroBase):
 
     @property
     def redireciona_para(self):
-        if self.retorno_de_requisicao:
+        if "next_url" in self.dados:
             tipo = self.tipo
             if self.situacao_aguardando:
                 tipo = 'pending'
